#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optional-args
version:              1.0.2
visibility:           public
id:                   optional-args-1.0.2-F0xejbU8T85GOpMOmS9nLh
key:                  optional-args-1.0.2-F0xejbU8T85GOpMOmS9nLh
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Optional function arguments
description:
    This library provides a type for specifying `Optional` function
    arguments

    Read the tutorial in "Data.Optional" to learn more

category:             Data
abi:                  074860e4158aed01ecfaf0f373666b57
exposed:              True
exposed-modules:      Data.Optional
import-dirs:          /usr/lib/ghc-9.6.6/site-local/optional-args-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optional-args-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optional-args-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optional-args
hs-libraries:         HSoptional-args-1.0.2-F0xejbU8T85GOpMOmS9nLh
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-optional-args/html/optional-args.haddock

haddock-html:         /usr/share/doc/haskell-optional-args/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

